@@ -55,7 +55,7 @@ class ReturnClass:
                 return False
             return True #for now everything else is True (may eventually need to add NaN or something...)
         except Exception as e:
-            print(e)
+            #print(e)
             raise(e)
             
     def __repr__(self):
