@@ -86,7 +86,7 @@ class Project:
                         index+=1
                         file_name=Path(file_path).stem+"_"+str(index)+Path(file_path).suffix
                         dst=os.path.join(self.directory, file_name)
-                    #print("renamed to: ", file_name)
+                    pass #print("renamed to: ", file_name)
                 else:
                     raise FileWithThatNameInProject(str(dst))
             try:
@@ -99,7 +99,7 @@ class Project:
     def add_data_file(self, file_path, copy_from_elsewhere=False, overwrite=False, rename=False):
         file_path=self._add_file(file_path, copy_from_elsewhere, overwrite, rename)
         if file_path in self.data_files:
-            #print("This file is already present in the project's data files")
+            pass #print("This file is already present in the project's data files")
         else:
             full_file_path=Path(self.directory) /  file_path
             sf = SpreadsheetFile(full_file_path)
@@ -110,7 +110,7 @@ class Project:
                         copy_from_elsewhere=False, overwrite=False, rename=False):
         file_path=self._add_file(file_path, copy_from_elsewhere, overwrite, rename)
         if file_path in self.yaml_files:
-            #print("This file is already present in the project's yaml files")
+            pass #print("This file is already present in the project's yaml files")
         else:
             self.yaml_files.append(file_path)
         if data_file and sheet_name:
@@ -134,7 +134,7 @@ class Project:
         if data_path in self.yaml_sheet_associations:
             try:
                 if yaml_path in self.yaml_sheet_associations[data_path][sheet_name]["val_arr"]:
-                    #print("that yaml association has already been added")
+                    pass #print("that yaml association has already been added")
                 else:
                     self.yaml_sheet_associations[data_path][sheet_name]["val_arr"].append(yaml_path)
             except KeyError:
@@ -145,7 +145,7 @@ class Project:
     def add_wikifier_file(self, file_path, copy_from_elsewhere=False, overwrite=False, rename=False, precedence=True):
         file_path=self._add_file(file_path, copy_from_elsewhere, overwrite, rename)
         if file_path in self.wikifier_files:
-            #print("This file is already present in the project's wikifier files")
+            pass #print("This file is already present in the project's wikifier files")
             self.wikifier_files.remove(file_path)
         
         if precedence:
@@ -161,7 +161,7 @@ class Project:
     def add_entity_file(self, file_path, copy_from_elsewhere=False, overwrite=False, rename=False, precedence=True):
         file_path=self._add_file(file_path, copy_from_elsewhere, overwrite, rename)
         if file_path in self.entity_files:
-            #print("This file is already present in the project's entity files")
+            pass #print("This file is already present in the project's entity files")
             self.entity_files.remove(file_path)
         if precedence:
             self.entity_files.append(file_path)
@@ -177,7 +177,7 @@ class Project:
         if data_path in self.annotations:
             try:
                 if annotation_path in self.annotations[data_path][sheet_name]["val_arr"]:
-                    #print("that yaml association has already been added")
+                    pass #print("that yaml association has already been added")
                 else:
                     self.annotations[data_path][sheet_name]["val_arr"].append(annotation_path)
             except KeyError:
@@ -256,7 +256,7 @@ class Project:
                 del_path=self.get_full_path(del_val)
                 os.remove(del_path)
             except Exception as e:
-                #print(e)
+                pass #print(e)
                 
     def rename_file_in_project(self, old_name, new_name, rename_in_fs=False):
         old_name=self._normalize_path(old_name)
