@@ -17,7 +17,7 @@ class T2WMLSettings:
             if os.path.isdir(self.cache_data_files_folder):
                 return True
             else:
-                #print("Cache folder in settings does not exist: "+self.cache_data_files_folder)
+                print("Cache folder in settings does not exist: "+self.cache_data_files_folder)
         return False
 
     def update_from_dict(self, **kwargs):
