@@ -1,4 +1,6 @@
 import logging
+t2wml_log=logging.getLogger("t2wml-api")
+t2wml_log.addHandler(logging.NullHandler())
 
 def basic_debug(func=None):
     def wrapper(*args, **kwargs):
@@ -6,13 +8,13 @@ def basic_debug(func=None):
             function_name = func.__func__.__qualname__
         except:
             function_name = func.__qualname__
-        logging.info(f"calling {function_name}")
+        t2wml_log.info(f"calling {function_name}")
         try:
             result= func(*args, **kwargs)
-            logging.info(f"returned from {function_name}")
+            t2wml_log.info(f"returned from {function_name}")
             return result
         except Exception as e:
-            logging.error(f"{function_name} raised {str(e)}")
+            t2wml_log.error(f"{function_name} raised {str(e)}")
             raise e
     return wrapper
 
@@ -22,13 +24,13 @@ def with_args_debug(func=None):
             function_name = func.__func__.__qualname__
         except:
             function_name = func.__qualname__
-        logging.info(f"calling {function_name}") 
-        logging.debug(f"with args {str(args)} and kwargs {str(kwargs)}")
+        t2wml_log.info(f"calling {function_name}") 
+        t2wml_log.debug(f"with args {str(args)} and kwargs {str(kwargs)}")
         try:
             result= func(*args, **kwargs)
-            logging.debug(f"{function_name} returned result: {result}")
+            t2wml_log.debug(f"{function_name} returned result: {result}")
             return result
         except Exception as e:
-            logging.error(f"{function_name} raised {str(e)}")
+            t2wml_log.error(f"{function_name} raised {str(e)}")
             raise e
     return wrapper
\ No newline at end of file
