@@ -152,12 +152,12 @@ class Wikifier:
     def print_data(self):
         """prints a little summary of the contents of the wikifier
         """
-        #print("The wikifier contains {} wiki files, and a total of {} dataframes".format(
+        print("The wikifier contains {} wiki files, and a total of {} dataframes".format(
             len(self.wiki_files), len(self._data_frames)))
         if len(self.wiki_files):
-            #print("The files are:")
+            print("The files are:")
             for filename in self.wiki_files:
-                #print(filename)
+                print(filename)
 
     @property
     def item_table(self):
