@@ -1,6 +1,5 @@
 from abc import ABC, abstractmethod
-import logging
-from t2wml.utils.debug_logging import basic_debug
+from t2wml.utils.debug_logging import basic_debug, t2wml_log
 from SPARQLWrapper import SPARQLWrapper, JSON
 from t2wml.settings import t2wml_settings
 
@@ -60,9 +59,9 @@ class SparqlProvider(WikidataProvider):
         sparql = SPARQLWrapper(self.sparql_endpoint, agent='Mozilla/5.0 (Macintosh; Intel Mac OS X 10_11_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/50.0.2661.102 Safari/537.36')
         sparql.setQuery(query)
         sparql.setReturnFormat(JSON)
-        logging.debug("SparlqProvider: sending the query: "+query)
+        t2wml_log.debug("SparlqProvider: sending the query: "+query)
         results = sparql.query().convert()
-        logging.debug("SparlqProvider: response to query received")
+        t2wml_log.debug("SparlqProvider: response to query received")
         try:
             results_0=results["results"]["bindings"][0]
             data_type = results_0["type"]["value"].split("#")[1]
